<?php
/*
Plugin Name: Live Flickr comment Importer
Plugin URI: http://sanisoft.com/blog/wordpress-plugin-live-flickr-comment-importer/
Description: Add Flickr comments to your blog posts which have embeded flickr photos.
Author: Tarique Sani
Version: 1.6
Author URI: http://tariquesani.net/blog/
*/ 

/*  Copyright 2009  Tarique Sani  (email : tarique@sanisoft.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

# Uncomment the next two lines to see error messages if things fail...
# error_reporting(E_ALL);
# ini_set("display_errors", 1); 

require_once ('phpflickr/phpFlickr.php');

function live_flickr_comment_importer($content) {
	global $wpdb, $post;
	
	// Return if it is not a single post
	if(!is_single()) {
		return $content;
	}
	
	$flickr_dont_import    = get_post_meta($post->ID, 'flickr_dont_import', true);
	
	// Return if don't import meta field is set
	if($flickr_dont_import) {
		return $content;
	}	

	$flickr_photo_id_array = explode(",", get_post_meta($post->ID, 'flickr_photo_id', true));
	
	$flickr_show_thumbnail = get_post_meta($post->ID, 'flickr_show_thumbnail', true);	
	

	//The post metadata does not have a flickr_photo_id - Try scanning the post for flickr image
	if(empty($flickr_photo_id_array[0])){
		$output = preg_match_all('/<img.+src=[\'"].*flickr.com\/.*\/([^\'"]+)_.*\.jpg[\'"].*>/i', $post->post_content, $matches);
		$flickr_photo_id_array = $matches [1];
	}

	// return if the post has no Flickr photo ID
	if(empty($flickr_photo_id_array[0])) {
		return $content;
	}		
	
	// Return if there is no Flickr API key
	$flickrapikey = get_option( 'flickrapikey' );
	if( !$flickrapikey ){
		return $content;
	}
	 	
	$f = new t_phpFlickr($flickrapikey);
	
	$f->enableCache('fs', ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/');
	
	foreach($flickr_photo_id_array as $flickr_photo_id){	
		$comments   = $f->photos_comments_getList($flickr_photo_id);
		
		if(!empty($flickr_show_thumbnail)){
			$photo_sizes = $f->photos_getSizes($flickr_photo_id);
			$square_thumb = $photo_sizes[0]['source']; 

			$photo_info = $f->photos_getInfo($flickr_photo_id);
		
			$title = $photo_info['title'];
		}
		$i = 0;
				
		//OK if there are comments then loop over them
		if(isset($comments['comments']['comment'])) {
			foreach( $comments['comments']['comment'] as $comment ) {
				
				// Is the comment already in the database? No! Add the damn thing!!
				
				$test_dupes = $wpdb->get_results( "SELECT comment_ID FROM {$wpdb->comments} WHERE comment_author_url='{$comment['permalink']}'", ARRAY_N);
				
				$has_dupes = count($test_dupes);
				
				if(empty($has_dupes)) {				
					// Get Author info so that you can build an Avatar URL later
					$author = $f->people_getInfo($comment['author']);
					if ($author['iconserver'] > 0){
						// This is cheating - there should be a differnt field for it 
						$commentdata['comment_author_IP'] 		= $author['iconserver'] ."++". $author['id'];
					}
					
					$commentdata['comment_author']		= "Flickr: ".wp_specialchars($comment['authorname']);
					$commentdata['comment_author_email']	= 'nobody@flickr.com';
					$commentdata['comment_author_url'] 	= wp_specialchars($comment['permalink']);
					
					if(!empty($flickr_show_thumbnail)){
						$commentdata['comment_content']		= "<img class='comment-thumb' src='".$square_thumb."' alt='".$title."' title='".$title."' width=30 >";
					} else {
						$commentdata['comment_content']		= "";
					}
					
					$commentdata['comment_content']			.= addslashes( strip_tags($comment['_content']) );
					$commentdata['comment_type']			= '';
					$commentdata['comment_date']			= date("Y-m-d H:i:s", $comment['datecreate'] ) ;
					$commentdata['comment_date_gmt'] 		= date("Y-m-d H:i:s", $comment['datecreate'] );			
					$commentdata['comment_post_ID'] 		= $post->ID;	
					$commentdata['user_ID']					= 0;
					$commentdata['comment_agent']     		= "Live Flickr Add Comment Agent";
					$commentdata['comment_approved'] 		= 1;
					$comment_ID = wp_insert_comment($commentdata);
				} else if($has_dupes > 1){
						for ($i = 1; $i < $has_dupes; $i++) {
    						$wpdb->query("DELETE FROM {$wpdb->comments} WHERE comment_id = '{$test_dupes[$i][0]}'");
						}
				}
			}
		}
	}
	return $content;
}

// All the blah functions to get the admin part going...
if ( ! function_exists('wp_nonce_field') ) {
	function lfci_nonce_field($action = -1) {
		return;	
	}
	$fci_nonce = -1;
} else {
	function lfci_nonce_field($action = -1) {
		return wp_nonce_field($action);
	}
	$fci_nonce = 'fci-update-key';
}

function lfci_config_page() {
	global $wpdb;
	if ( function_exists('add_submenu_page') )
		add_submenu_page('options-general.php', __('Live Flickr Comments'), __('Live Flickr Comments'), 'manage_options', __FILE__, 'lfci_conf');
}

function lfci_conf() {
	global $fci_nonce;
	if ( isset($_POST['submit']) ) {
		if ( function_exists('current_user_can') && !current_user_can('manage_options') )
			die(__('Cheatin&#8217; uh?'));

		check_admin_referer($fci_nonce);
		
		//Verify API key
		$f = new t_phpFlickr( $_POST[ 'flickrapikey' ] );
		
		if($f->test_echo() === false) {
			$invalid_key = true;
		} else {
			update_option( 'flickrapikey', $_POST[ 'flickrapikey' ] );
		}
	}
?>

<div class="wrap">
<h2><?php _e('Live Flickr Comment Importer'); ?></h2>
	<p><?php _e( "If you use Flickr to host your photos this plugin will import the comments from your Flickr stream into your blog posts. Enter the a Flickr API key which you can get from <a href='http://www.flickr.com/services/apps/create/apply/' >http://www.flickr.com/services/apps/create/apply/</a> in the box below." );?></p>
<form action="" method="post" id="fci-conf" style="margin: auto; ">
<?php lfci_nonce_field($fci_nonce) ?>
<h3><label for="key"><?php _e('Flickr Api Key'); ?></label></h3>
<p><input id="url" name="flickrapikey" type="text" size="30" maxlength="300" value="<?php echo get_option('flickrapikey'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /></p>
<?php if ( $invalid_key ) { ?>
	<p style="padding: .5em; background-color: #f33; color: #fff; font-weight: bold; width: 30em"><?php _e('That is not a valid Flickr API key'); ?></p>
<?php } ?>
	<p class="submit"><input type="submit" name="submit" value="<?php _e('Update API key &raquo;'); ?>" /></p>
</form>
<?php if ( !is_writeable(ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/') ) { ?>
	<p style="padding: .5em; background-color: #f33; color: #fff; font-weight: bold; width: 50em"><?php _e('WARNING: Your cache path '.ABSPATH . 'wp-content/plugins/live-flickr-comment-importer/phpflickr/cache/'.' is not writeable by the webserver. Please change permissions to make it writeable'); ?></p>
<?php } ?>

	<p><?php _e( "<strong>Usage</strong><br /><ul><li>The Flickr image(s) must be embedded in your post <strong>OR</strong></li> <li> Your posts must have a custom field called 'flickr_photo_id' with the value as ID of the photo on Flickr whose comments you want to import in the post. Use comma to separate multiple values.</li><li>Flickr Photo ID is usually the last number in the URL of the photo page eg: In <a href='http://www.flickr.com/photos/tariquesani/4175454833/'>http://www.flickr.com/photos/tariquesani/4175454833/</a> - 4175454833 is the photo ID</li><li>See how to <a href='http://www.boosten.org/using-custom-fields-in-wordpress-posts/' >include a custom field in your post</a>.</li>
<li>Use custom field called 'flickr_dont_import' to prevent comment import</li>
<li>Use custom field called 'flickr_show_thumbnail' to show a small thumnail of the photo on which comment is made - useful in cases of multiple photos</li>
<li>Comments will be imported whenever someone visits the post</li></ul>" );?></p>

<p><?php _e( "Don't forget to visit my blog at <a href='http://tariquesani.net/blog/'>http://tariquesani.net/blog/</a>." ); ?>
</div>
<?php
}

// If the comment is from Flickr build the avatar from Flickr data
// Second param is not reliable when wanting to get the comment object so 
// calling it $blah
function get_flickr_avatar($avatar, $blah, $size) {
	global $comment;
		if($comment->comment_author_email == 'nobody@flickr.com'){
			$tmp = explode("++",$comment->comment_author_IP);
			$avatar = "<img alt='' src='http://static.flickr.com/{$tmp[0]}/buddyicons/{$tmp[1]}.jpg' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
		}		
		return $avatar;
}

add_filter( 'get_avatar','get_flickr_avatar', 1, 3 );
add_filter('the_content', 'live_flickr_comment_importer');
add_action('admin_menu', 'lfci_config_page');

?>
